==> haskell-persistent-2.7.0-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.7.0
id: persistent-2.7.0-DjUoJX0d0HtFg1tSRHDRWr
key: persistent-2.7.0-DjUoJX0d0HtFg1tSRHDRWr
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Database.Persist Database.Persist.Class Database.Persist.Quasi
    Database.Persist.Sql Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.Types
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
abi: bf99215a51471998a0d43c73cbc43cfb
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/persistent-2.7.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/persistent-2.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/persistent-2.7.0
hs-libraries: HSpersistent-2.7.0-DjUoJX0d0HtFg1tSRHDRWr
depends:
    base-4.10.0.0 bytestring-0.10.8.2 transformers-0.5.2.0 time-1.8.0.2
    old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz containers-0.5.10.2
    conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj
    lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ
    resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG
    path-pieces-0.2.1-3aB5yqkjw3g6TYHBL5lTHL
    http-api-data-0.3.7.1-F355QzB7S4d4QWa0UqTiBa
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    monad-logger-0.3.25.1-8lZjdCQwuyLHjwWHPCsxdR
    transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    template-haskell-2.12.0.0 blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL
    silently-1.2.5-4d48ibUelDmLXErYHoAYYi
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=bb3d8fbe7de4d3cc9ed854226de736b7
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1=60ad65370a9da57d3d90715264a4baf8
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=f1e3985ff4759dcc429559c38ecdf6c4
             lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ=bb85cfc6c0da3429f07db4d32d334f57
             resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG=5b077650442ac89e21628081801bbe25
             path-pieces-0.2.1-3aB5yqkjw3g6TYHBL5lTHL=dcfd026032dd0d832f017a3c72f66f54
             http-api-data-0.3.7.1-F355QzB7S4d4QWa0UqTiBa=7a9614be7f781e3587ce5da9b0853406
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             monad-logger-0.3.25.1-8lZjdCQwuyLHjwWHPCsxdR=4a866108f3c15e274103501b95a15632
             transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld=33975d5ab4ac245dea75155525ae62b2
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             silently-1.2.5-4d48ibUelDmLXErYHoAYYi=db9d954db275cd5425231a2f34f07d0e
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7=4fe9e3cb4687ed21d88fd96f3fa94e5f
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG=ef0c2166834103b504bc3792a7d2c177
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.7.0-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.7.0
id: persistent-2.7.0-I8wmVXOMY0i6N2WQ58UsGf
key: persistent-2.7.0-I8wmVXOMY0i6N2WQ58UsGf
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Database.Persist Database.Persist.Class Database.Persist.Quasi
    Database.Persist.Sql Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.Types
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
abi: 0a883e81ff66daefc8c1ce095fde395d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/persistent-2.7.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/persistent-2.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/persistent-2.7.0
hs-libraries: HSpersistent-2.7.0-I8wmVXOMY0i6N2WQ58UsGf
depends:
    base-4.10.0.0 bytestring-0.10.8.2 transformers-0.5.2.0 time-1.8.0.2
    old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz containers-0.5.10.2
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj
    lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ
    resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG
    path-pieces-0.2.1-3aB5yqkjw3g6TYHBL5lTHL
    http-api-data-0.3.7.1-F355QzB7S4d4QWa0UqTiBa
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i
    transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    template-haskell-2.12.0.0 blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL
    silently-1.2.5-4d48ibUelDmLXErYHoAYYi
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=bb3d8fbe7de4d3cc9ed854226de736b7
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=52e9aaa2724a9edb2ade5ee067f8810a
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=f1e3985ff4759dcc429559c38ecdf6c4
             lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ=bb85cfc6c0da3429f07db4d32d334f57
             resource-pool-0.2.3.2-Lvu8b2azqmPDyhUQPYb0gG=5b077650442ac89e21628081801bbe25
             path-pieces-0.2.1-3aB5yqkjw3g6TYHBL5lTHL=dcfd026032dd0d832f017a3c72f66f54
             http-api-data-0.3.7.1-F355QzB7S4d4QWa0UqTiBa=7a9614be7f781e3587ce5da9b0853406
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i=5ca2af848924c38076b16946ad67a1a4
             transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld=33975d5ab4ac245dea75155525ae62b2
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             silently-1.2.5-4d48ibUelDmLXErYHoAYYi=db9d954db275cd5425231a2f34f07d0e
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7=4fe9e3cb4687ed21d88fd96f3fa94e5f
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG=ef0c2166834103b504bc3792a7d2c177
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
